@@ -20,9 +20,6 @@ def catch_exceptions(func):
             return functools.partial(catch_exceptions)
         try:
             return func(*args, **kwargs)
-        except exceptions.RobotidyConfigError as err:
-            print(f"Error: {err}")
-            sys.exit(1)
         except (click.exceptions.ClickException, click.exceptions.Exit):
             raise
         except Exception as err:
@@ -30,7 +27,7 @@ def catch_exceptions(func):
                 "\nFatal exception occurred. You can create an issue at "
                 "https://github.com/MarketSquare/robotframework-tidy/issues . Thanks!"
             )
-            err.args = (err.args[0] + message,) + err.args[1:]
+            err.args = (str(err.args[0]) + message,) + err.args[1:]
             raise err
 
     return wrapper
